site

package
v0.2.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Sep 9, 2020 License: Apache-2.0 Imports: 5 Imported by: 6

Documentation

Index

Constants

This section is empty.

Variables

var AssetFragment_State_name = map[int32]string{
	0: "Reserved",
	1: "Pending",
	2: "Reticulating",
	3: "Complete",
	4: "Error",
}
var AssetFragment_State_value = map[string]int32{
	"Reserved":     0,
	"Pending":      1,
	"Reticulating": 2,
	"Complete":     3,
	"Error":        4,
}
var Diagnostic_Code_name = map[int32]string{
	0: "Trace",
	1: "Debug",
	2: "Info",
	3: "Warn",
	4: "Error",
	5: "Critical",
}
var Diagnostic_Code_value = map[string]int32{
	"Trace":    0,
	"Debug":    1,
	"Info":     2,
	"Warn":     3,
	"Error":    4,
	"Critical": 5,
}
var IncomingRequest_Code_name = map[int32]string{
	0: "Reserved",
	1: "Setup",
	2: "Teardown",
}
var IncomingRequest_Code_value = map[string]int32{
	"Reserved": 0,
	"Setup":    1,
	"Teardown": 2,
}
var MzFragment_State_name = map[int32]string{
	0: "Reserved",
	1: "Pending",
	2: "Reticulating",
	3: "Complete",
	4: "Error",
}
var MzFragment_State_value = map[string]int32{
	"Reserved":     0,
	"Pending":      1,
	"Reticulating": 2,
	"Complete":     3,
	"Error":        4,
}

Functions

func RegisterAssetDriverServer added in v0.2.0

func RegisterAssetDriverServer(s *grpc.Server, srv AssetDriverServer)

func RegisterCommanderServer

func RegisterCommanderServer(s *grpc.Server, srv CommanderServer)

func RegisterDriverServer

func RegisterDriverServer(s *grpc.Server, srv DriverServer)

func RegisterLinkDriverServer

func RegisterLinkDriverServer(s *grpc.Server, srv LinkDriverServer)

func RegisterNodeDriverServer

func RegisterNodeDriverServer(s *grpc.Server, srv NodeDriverServer)

Types

type AssetDriverClient added in v0.2.0

type AssetDriverClient interface {
	Health(ctx context.Context, in *HealthRequest, opts ...grpc.CallOption) (*HealthResponse, error)
	CreateVolume(ctx context.Context, in *MzRequest, opts ...grpc.CallOption) (*MzResponse, error)
	DestroyVolume(ctx context.Context, in *MzRequest, opts ...grpc.CallOption) (*MzResponse, error)
	ModifyVolume(ctx context.Context, in *MzRequest, opts ...grpc.CallOption) (*MzResponse, error)
	Createemage(ctx context.Context, in *MzRequest, opts ...grpc.CallOption) (*MzResponse, error)
	ModifyImage(ctx context.Context, in *MzRequest, opts ...grpc.CallOption) (*MzResponse, error)
	NotifyIncoming(ctx context.Context, in *IncomingRequest, opts ...grpc.CallOption) (*IncomingResponse, error)
}

AssetDriverClient is the client API for AssetDriver service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.

func NewAssetDriverClient added in v0.2.0

func NewAssetDriverClient(cc *grpc.ClientConn) AssetDriverClient

type AssetDriverServer added in v0.2.0

type AssetDriverServer interface {
	Health(context.Context, *HealthRequest) (*HealthResponse, error)
	CreateVolume(context.Context, *MzRequest) (*MzResponse, error)
	DestroyVolume(context.Context, *MzRequest) (*MzResponse, error)
	ModifyVolume(context.Context, *MzRequest) (*MzResponse, error)
	Createemage(context.Context, *MzRequest) (*MzResponse, error)
	ModifyImage(context.Context, *MzRequest) (*MzResponse, error)
	NotifyIncoming(context.Context, *IncomingRequest) (*IncomingResponse, error)
}

AssetDriverServer is the server API for AssetDriver service.

type AssetFragment added in v0.2.0

type AssetFragment struct {
	Id                   string              `protobuf:"bytes,1,opt,name=id,proto3" json:"id,omitempty"`
	Resources            []string            `protobuf:"bytes,2,rep,name=resources,proto3" json:"resources,omitempty"`
	Model                *AssetModel         `protobuf:"bytes,3,opt,name=model,proto3" json:"model,omitempty"`
	State                AssetFragment_State `protobuf:"varint,4,opt,name=state,proto3,enum=site.AssetFragment_State" json:"state,omitempty"`
	Error                string              `protobuf:"bytes,5,opt,name=error,proto3" json:"error,omitempty"`
	XXX_NoUnkeyedLiteral struct{}            `json:"-" yaml:"-"`
	XXX_unrecognized     []byte              `json:"-" yaml:"-"`
	XXX_sizecache        int32               `json:"-" yaml:"-"`
}

func (*AssetFragment) Descriptor added in v0.2.0

func (*AssetFragment) Descriptor() ([]byte, []int)

func (*AssetFragment) GetError added in v0.2.0

func (m *AssetFragment) GetError() string

func (*AssetFragment) GetId added in v0.2.0

func (m *AssetFragment) GetId() string

func (*AssetFragment) GetModel added in v0.2.0

func (m *AssetFragment) GetModel() *AssetModel

func (*AssetFragment) GetResources added in v0.2.0

func (m *AssetFragment) GetResources() []string

func (*AssetFragment) GetState added in v0.2.0

func (m *AssetFragment) GetState() AssetFragment_State

func (*AssetFragment) ProtoMessage added in v0.2.0

func (*AssetFragment) ProtoMessage()

func (*AssetFragment) Reset added in v0.2.0

func (m *AssetFragment) Reset()

func (*AssetFragment) String added in v0.2.0

func (m *AssetFragment) String() string

func (*AssetFragment) XXX_DiscardUnknown added in v0.2.0

func (m *AssetFragment) XXX_DiscardUnknown()

func (*AssetFragment) XXX_Marshal added in v0.2.0

func (m *AssetFragment) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)

func (*AssetFragment) XXX_Merge added in v0.2.0

func (m *AssetFragment) XXX_Merge(src proto.Message)

func (*AssetFragment) XXX_Size added in v0.2.0

func (m *AssetFragment) XXX_Size() int

func (*AssetFragment) XXX_Unmarshal added in v0.2.0

func (m *AssetFragment) XXX_Unmarshal(b []byte) error

type AssetFragment_State added in v0.2.0

type AssetFragment_State int32
const (
	AssetFragment_Reserved     AssetFragment_State = 0
	AssetFragment_Pending      AssetFragment_State = 1
	AssetFragment_Reticulating AssetFragment_State = 2
	AssetFragment_Complete     AssetFragment_State = 3
	AssetFragment_Error        AssetFragment_State = 4
)

func (AssetFragment_State) EnumDescriptor added in v0.2.0

func (AssetFragment_State) EnumDescriptor() ([]byte, []int)

func (AssetFragment_State) String added in v0.2.0

func (x AssetFragment_State) String() string

type AssetModel added in v0.2.0

type AssetModel struct {
	Model                string   `protobuf:"bytes,1,opt,name=model,proto3" json:"model,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-" yaml:"-"`
	XXX_unrecognized     []byte   `json:"-" yaml:"-"`
	XXX_sizecache        int32    `json:"-" yaml:"-"`
}

func (*AssetModel) Descriptor added in v0.2.0

func (*AssetModel) Descriptor() ([]byte, []int)

func (*AssetModel) GetModel added in v0.2.0

func (m *AssetModel) GetModel() string

func (*AssetModel) ProtoMessage added in v0.2.0

func (*AssetModel) ProtoMessage()

func (*AssetModel) Reset added in v0.2.0

func (m *AssetModel) Reset()

func (*AssetModel) String added in v0.2.0

func (m *AssetModel) String() string

func (*AssetModel) XXX_DiscardUnknown added in v0.2.0

func (m *AssetModel) XXX_DiscardUnknown()

func (*AssetModel) XXX_Marshal added in v0.2.0

func (m *AssetModel) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)

func (*AssetModel) XXX_Merge added in v0.2.0

func (m *AssetModel) XXX_Merge(src proto.Message)

func (*AssetModel) XXX_Size added in v0.2.0

func (m *AssetModel) XXX_Size() int

func (*AssetModel) XXX_Unmarshal added in v0.2.0

func (m *AssetModel) XXX_Unmarshal(b []byte) error

type AssetRequest added in v0.2.0

type AssetRequest struct {
	Assetid              string           `protobuf:"bytes,1,opt,name=assetid,proto3" json:"assetid,omitempty"`
	Fragments            []*AssetFragment `protobuf:"bytes,2,rep,name=fragments,proto3" json:"fragments,omitempty"`
	XXX_NoUnkeyedLiteral struct{}         `json:"-" yaml:"-"`
	XXX_unrecognized     []byte           `json:"-" yaml:"-"`
	XXX_sizecache        int32            `json:"-" yaml:"-"`
}

func (*AssetRequest) Descriptor added in v0.2.0

func (*AssetRequest) Descriptor() ([]byte, []int)

func (*AssetRequest) GetAssetid added in v0.2.0

func (m *AssetRequest) GetAssetid() string

func (*AssetRequest) GetFragments added in v0.2.0

func (m *AssetRequest) GetFragments() []*AssetFragment

func (*AssetRequest) ProtoMessage added in v0.2.0

func (*AssetRequest) ProtoMessage()

func (*AssetRequest) Reset added in v0.2.0

func (m *AssetRequest) Reset()

func (*AssetRequest) String added in v0.2.0

func (m *AssetRequest) String() string

func (*AssetRequest) XXX_DiscardUnknown added in v0.2.0

func (m *AssetRequest) XXX_DiscardUnknown()

func (*AssetRequest) XXX_Marshal added in v0.2.0

func (m *AssetRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)

func (*AssetRequest) XXX_Merge added in v0.2.0

func (m *AssetRequest) XXX_Merge(src proto.Message)

func (*AssetRequest) XXX_Size added in v0.2.0

func (m *AssetRequest) XXX_Size() int

func (*AssetRequest) XXX_Unmarshal added in v0.2.0

func (m *AssetRequest) XXX_Unmarshal(b []byte) error

type AssetResponse added in v0.2.0

type AssetResponse struct {
	Assetid              string           `protobuf:"bytes,1,opt,name=assetid,proto3" json:"assetid,omitempty"`
	Msg                  []*Diagnostic    `protobuf:"bytes,2,rep,name=msg,proto3" json:"msg,omitempty"`
	Updates              []*AssetFragment `protobuf:"bytes,3,rep,name=updates,proto3" json:"updates,omitempty"`
	XXX_NoUnkeyedLiteral struct{}         `json:"-" yaml:"-"`
	XXX_unrecognized     []byte           `json:"-" yaml:"-"`
	XXX_sizecache        int32            `json:"-" yaml:"-"`
}

func (*AssetResponse) Descriptor added in v0.2.0

func (*AssetResponse) Descriptor() ([]byte, []int)

func (*AssetResponse) GetAssetid added in v0.2.0

func (m *AssetResponse) GetAssetid() string

func (*AssetResponse) GetMsg added in v0.2.0

func (m *AssetResponse) GetMsg() []*Diagnostic

func (*AssetResponse) GetUpdates added in v0.2.0

func (m *AssetResponse) GetUpdates() []*AssetFragment

func (*AssetResponse) ProtoMessage added in v0.2.0

func (*AssetResponse) ProtoMessage()

func (*AssetResponse) Reset added in v0.2.0

func (m *AssetResponse) Reset()

func (*AssetResponse) String added in v0.2.0

func (m *AssetResponse) String() string

func (*AssetResponse) XXX_DiscardUnknown added in v0.2.0

func (m *AssetResponse) XXX_DiscardUnknown()

func (*AssetResponse) XXX_Marshal added in v0.2.0

func (m *AssetResponse) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)

func (*AssetResponse) XXX_Merge added in v0.2.0

func (m *AssetResponse) XXX_Merge(src proto.Message)

func (*AssetResponse) XXX_Size added in v0.2.0

func (m *AssetResponse) XXX_Size() int

func (*AssetResponse) XXX_Unmarshal added in v0.2.0

func (m *AssetResponse) XXX_Unmarshal(b []byte) error

type CommanderClient

type CommanderClient interface {
	// Genral commands
	Health(ctx context.Context, in *HealthRequest, opts ...grpc.CallOption) (*HealthResponse, error)
	Register(ctx context.Context, in *RegisterRequest, opts ...grpc.CallOption) (*RegisterResponse, error)
	Unregister(ctx context.Context, in *UnregisterRequest, opts ...grpc.CallOption) (*UnregisterResponse, error)
	NotifyIncoming(ctx context.Context, in *IncomingRequest, opts ...grpc.CallOption) (*IncomingResponse, error)
	Status(ctx context.Context, in *StatusRequest, opts ...grpc.CallOption) (*StatusResponse, error)
	// Node commands
	Setup(ctx context.Context, in *MzRequest, opts ...grpc.CallOption) (*MzResponse, error)
	Recycle(ctx context.Context, in *MzRequest, opts ...grpc.CallOption) (*MzResponse, error)
	Configure(ctx context.Context, in *MzRequest, opts ...grpc.CallOption) (*MzResponse, error)
	Restart(ctx context.Context, in *MzRequest, opts ...grpc.CallOption) (*MzResponse, error)
	Reset(ctx context.Context, in *MzRequest, opts ...grpc.CallOption) (*MzResponse, error)
	TurnOn(ctx context.Context, in *MzRequest, opts ...grpc.CallOption) (*MzResponse, error)
	TurnOff(ctx context.Context, in *MzRequest, opts ...grpc.CallOption) (*MzResponse, error)
	// Link commands
	CreateLink(ctx context.Context, in *MzRequest, opts ...grpc.CallOption) (*MzResponse, error)
	DestroyLink(ctx context.Context, in *MzRequest, opts ...grpc.CallOption) (*MzResponse, error)
	ModifyLink(ctx context.Context, in *MzRequest, opts ...grpc.CallOption) (*MzResponse, error)
	ConnectLink(ctx context.Context, in *MzRequest, opts ...grpc.CallOption) (*MzResponse, error)
	DisconnectLink(ctx context.Context, in *MzRequest, opts ...grpc.CallOption) (*MzResponse, error)
	// Asset commands
	CreateVolume(ctx context.Context, in *MzRequest, opts ...grpc.CallOption) (*MzResponse, error)
	DestroyVolume(ctx context.Context, in *MzRequest, opts ...grpc.CallOption) (*MzResponse, error)
	ModifyVolume(ctx context.Context, in *MzRequest, opts ...grpc.CallOption) (*MzResponse, error)
	CreateImage(ctx context.Context, in *MzRequest, opts ...grpc.CallOption) (*MzResponse, error)
	DestroyImage(ctx context.Context, in *MzRequest, opts ...grpc.CallOption) (*MzResponse, error)
	// Asset static commands- out of band with experiment
	CreateSiteVolume(ctx context.Context, in *AssetRequest, opts ...grpc.CallOption) (*AssetResponse, error)
	DestroySiteVolume(ctx context.Context, in *AssetRequest, opts ...grpc.CallOption) (*AssetResponse, error)
	ModifySiteVolume(ctx context.Context, in *AssetRequest, opts ...grpc.CallOption) (*AssetResponse, error)
}

CommanderClient is the client API for Commander service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.

func NewCommanderClient

func NewCommanderClient(cc *grpc.ClientConn) CommanderClient

type CommanderServer

type CommanderServer interface {
	// Genral commands
	Health(context.Context, *HealthRequest) (*HealthResponse, error)
	Register(context.Context, *RegisterRequest) (*RegisterResponse, error)
	Unregister(context.Context, *UnregisterRequest) (*UnregisterResponse, error)
	NotifyIncoming(context.Context, *IncomingRequest) (*IncomingResponse, error)
	Status(context.Context, *StatusRequest) (*StatusResponse, error)
	// Node commands
	Setup(context.Context, *MzRequest) (*MzResponse, error)
	Recycle(context.Context, *MzRequest) (*MzResponse, error)
	Configure(context.Context, *MzRequest) (*MzResponse, error)
	Restart(context.Context, *MzRequest) (*MzResponse, error)
	Reset(context.Context, *MzRequest) (*MzResponse, error)
	TurnOn(context.Context, *MzRequest) (*MzResponse, error)
	TurnOff(context.Context, *MzRequest) (*MzResponse, error)
	// Link commands
	CreateLink(context.Context, *MzRequest) (*MzResponse, error)
	DestroyLink(context.Context, *MzRequest) (*MzResponse, error)
	ModifyLink(context.Context, *MzRequest) (*MzResponse, error)
	ConnectLink(context.Context, *MzRequest) (*MzResponse, error)
	DisconnectLink(context.Context, *MzRequest) (*MzResponse, error)
	// Asset commands
	CreateVolume(context.Context, *MzRequest) (*MzResponse, error)
	DestroyVolume(context.Context, *MzRequest) (*MzResponse, error)
	ModifyVolume(context.Context, *MzRequest) (*MzResponse, error)
	CreateImage(context.Context, *MzRequest) (*MzResponse, error)
	DestroyImage(context.Context, *MzRequest) (*MzResponse, error)
	// Asset static commands- out of band with experiment
	CreateSiteVolume(context.Context, *AssetRequest) (*AssetResponse, error)
	DestroySiteVolume(context.Context, *AssetRequest) (*AssetResponse, error)
	ModifySiteVolume(context.Context, *AssetRequest) (*AssetResponse, error)
}

CommanderServer is the server API for Commander service.

type Configure

type Configure struct {
	Json                 string   `protobuf:"bytes,1,opt,name=json,proto3" json:"json,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (*Configure) Descriptor

func (*Configure) Descriptor() ([]byte, []int)

func (*Configure) GetJson

func (m *Configure) GetJson() string

func (*Configure) ProtoMessage

func (*Configure) ProtoMessage()

func (*Configure) Reset

func (m *Configure) Reset()

func (*Configure) String

func (m *Configure) String() string

func (*Configure) XXX_DiscardUnknown

func (m *Configure) XXX_DiscardUnknown()

func (*Configure) XXX_Marshal

func (m *Configure) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)

func (*Configure) XXX_Merge

func (m *Configure) XXX_Merge(src proto.Message)

func (*Configure) XXX_Size

func (m *Configure) XXX_Size() int

func (*Configure) XXX_Unmarshal

func (m *Configure) XXX_Unmarshal(b []byte) error

type Diagnostic

type Diagnostic struct {
	Code                 Diagnostic_Code   `protobuf:"varint,1,opt,name=code,proto3,enum=site.Diagnostic_Code" json:"code,omitempty"`
	Msg                  string            `protobuf:"bytes,2,opt,name=msg,proto3" json:"msg,omitempty"`
	Fields               map[string]string `` /* 153-byte string literal not displayed */
	XXX_NoUnkeyedLiteral struct{}          `json:"-" yaml:"-"`
	XXX_unrecognized     []byte            `json:"-" yaml:"-"`
	XXX_sizecache        int32             `json:"-" yaml:"-"`
}

top level messages used by other messages

func (*Diagnostic) Descriptor

func (*Diagnostic) Descriptor() ([]byte, []int)

func (*Diagnostic) GetCode

func (m *Diagnostic) GetCode() Diagnostic_Code

func (*Diagnostic) GetFields

func (m *Diagnostic) GetFields() map[string]string

func (*Diagnostic) GetMsg

func (m *Diagnostic) GetMsg() string

func (*Diagnostic) ProtoMessage

func (*Diagnostic) ProtoMessage()

func (*Diagnostic) Reset

func (m *Diagnostic) Reset()

func (*Diagnostic) String

func (m *Diagnostic) String() string

func (*Diagnostic) XXX_DiscardUnknown

func (m *Diagnostic) XXX_DiscardUnknown()

func (*Diagnostic) XXX_Marshal

func (m *Diagnostic) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)

func (*Diagnostic) XXX_Merge

func (m *Diagnostic) XXX_Merge(src proto.Message)

func (*Diagnostic) XXX_Size

func (m *Diagnostic) XXX_Size() int

func (*Diagnostic) XXX_Unmarshal

func (m *Diagnostic) XXX_Unmarshal(b []byte) error

type Diagnostic_Code

type Diagnostic_Code int32

use standard 5 level code

const (
	Diagnostic_Trace    Diagnostic_Code = 0
	Diagnostic_Debug    Diagnostic_Code = 1
	Diagnostic_Info     Diagnostic_Code = 2
	Diagnostic_Warn     Diagnostic_Code = 3
	Diagnostic_Error    Diagnostic_Code = 4
	Diagnostic_Critical Diagnostic_Code = 5
)

func (Diagnostic_Code) EnumDescriptor

func (Diagnostic_Code) EnumDescriptor() ([]byte, []int)

func (Diagnostic_Code) String

func (x Diagnostic_Code) String() string

type DriverClient

type DriverClient interface {
	Health(ctx context.Context, in *HealthRequest, opts ...grpc.CallOption) (*HealthResponse, error)
	Status(ctx context.Context, in *StatusRequest, opts ...grpc.CallOption) (*StatusResponse, error)
	// Node commands
	Setup(ctx context.Context, in *MzRequest, opts ...grpc.CallOption) (*MzResponse, error)
	Recycle(ctx context.Context, in *MzRequest, opts ...grpc.CallOption) (*MzResponse, error)
	Configure(ctx context.Context, in *MzRequest, opts ...grpc.CallOption) (*MzResponse, error)
	Restart(ctx context.Context, in *MzRequest, opts ...grpc.CallOption) (*MzResponse, error)
	Reset(ctx context.Context, in *MzRequest, opts ...grpc.CallOption) (*MzResponse, error)
	TurnOn(ctx context.Context, in *MzRequest, opts ...grpc.CallOption) (*MzResponse, error)
	TurnOff(ctx context.Context, in *MzRequest, opts ...grpc.CallOption) (*MzResponse, error)
	// Link commands
	CreateLink(ctx context.Context, in *MzRequest, opts ...grpc.CallOption) (*MzResponse, error)
	DestroyLink(ctx context.Context, in *MzRequest, opts ...grpc.CallOption) (*MzResponse, error)
	ModifyLink(ctx context.Context, in *MzRequest, opts ...grpc.CallOption) (*MzResponse, error)
	ConnectLink(ctx context.Context, in *MzRequest, opts ...grpc.CallOption) (*MzResponse, error)
	DisconnectLink(ctx context.Context, in *MzRequest, opts ...grpc.CallOption) (*MzResponse, error)
	// Assets commands
	CreateVolume(ctx context.Context, in *MzRequest, opts ...grpc.CallOption) (*MzResponse, error)
	DestroyVolume(ctx context.Context, in *MzRequest, opts ...grpc.CallOption) (*MzResponse, error)
	ModifyVolume(ctx context.Context, in *MzRequest, opts ...grpc.CallOption) (*MzResponse, error)
	CreateImage(ctx context.Context, in *MzRequest, opts ...grpc.CallOption) (*MzResponse, error)
	DestroyImage(ctx context.Context, in *MzRequest, opts ...grpc.CallOption) (*MzResponse, error)
	// Assets commands
	CreateSiteVolume(ctx context.Context, in *AssetRequest, opts ...grpc.CallOption) (*AssetResponse, error)
	DestroySiteVolume(ctx context.Context, in *AssetRequest, opts ...grpc.CallOption) (*AssetResponse, error)
	ModifySiteVolume(ctx context.Context, in *AssetRequest, opts ...grpc.CallOption) (*AssetResponse, error)
	NotifyIncoming(ctx context.Context, in *IncomingRequest, opts ...grpc.CallOption) (*IncomingResponse, error)
}

DriverClient is the client API for Driver service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.

func NewDriverClient

func NewDriverClient(cc *grpc.ClientConn) DriverClient

type DriverServer

type DriverServer interface {
	Health(context.Context, *HealthRequest) (*HealthResponse, error)
	Status(context.Context, *StatusRequest) (*StatusResponse, error)
	// Node commands
	Setup(context.Context, *MzRequest) (*MzResponse, error)
	Recycle(context.Context, *MzRequest) (*MzResponse, error)
	Configure(context.Context, *MzRequest) (*MzResponse, error)
	Restart(context.Context, *MzRequest) (*MzResponse, error)
	Reset(context.Context, *MzRequest) (*MzResponse, error)
	TurnOn(context.Context, *MzRequest) (*MzResponse, error)
	TurnOff(context.Context, *MzRequest) (*MzResponse, error)
	// Link commands
	CreateLink(context.Context, *MzRequest) (*MzResponse, error)
	DestroyLink(context.Context, *MzRequest) (*MzResponse, error)
	ModifyLink(context.Context, *MzRequest) (*MzResponse, error)
	ConnectLink(context.Context, *MzRequest) (*MzResponse, error)
	DisconnectLink(context.Context, *MzRequest) (*MzResponse, error)
	// Assets commands
	CreateVolume(context.Context, *MzRequest) (*MzResponse, error)
	DestroyVolume(context.Context, *MzRequest) (*MzResponse, error)
	ModifyVolume(context.Context, *MzRequest) (*MzResponse, error)
	CreateImage(context.Context, *MzRequest) (*MzResponse, error)
	DestroyImage(context.Context, *MzRequest) (*MzResponse, error)
	// Assets commands
	CreateSiteVolume(context.Context, *AssetRequest) (*AssetResponse, error)
	DestroySiteVolume(context.Context, *AssetRequest) (*AssetResponse, error)
	ModifySiteVolume(context.Context, *AssetRequest) (*AssetResponse, error)
	NotifyIncoming(context.Context, *IncomingRequest) (*IncomingResponse, error)
}

DriverServer is the server API for Driver service.

type HealthRequest

type HealthRequest struct {
	XXX_NoUnkeyedLiteral struct{} `json:"-" yaml:"-"`
	XXX_unrecognized     []byte   `json:"-" yaml:"-"`
	XXX_sizecache        int32    `json:"-" yaml:"-"`
}

func (*HealthRequest) Descriptor

func (*HealthRequest) Descriptor() ([]byte, []int)

func (*HealthRequest) ProtoMessage

func (*HealthRequest) ProtoMessage()

func (*HealthRequest) Reset

func (m *HealthRequest) Reset()

func (*HealthRequest) String

func (m *HealthRequest) String() string

func (*HealthRequest) XXX_DiscardUnknown

func (m *HealthRequest) XXX_DiscardUnknown()

func (*HealthRequest) XXX_Marshal

func (m *HealthRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)

func (*HealthRequest) XXX_Merge

func (m *HealthRequest) XXX_Merge(src proto.Message)

func (*HealthRequest) XXX_Size

func (m *HealthRequest) XXX_Size() int

func (*HealthRequest) XXX_Unmarshal

func (m *HealthRequest) XXX_Unmarshal(b []byte) error

type HealthResponse

type HealthResponse struct {
	Drivers              int32    `protobuf:"varint,1,opt,name=drivers,proto3" json:"drivers,omitempty"`
	HealthyDrivers       int32    `protobuf:"varint,2,opt,name=healthy_drivers,json=healthyDrivers,proto3" json:"healthy_drivers,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-" yaml:"-"`
	XXX_unrecognized     []byte   `json:"-" yaml:"-"`
	XXX_sizecache        int32    `json:"-" yaml:"-"`
}

func (*HealthResponse) Descriptor

func (*HealthResponse) Descriptor() ([]byte, []int)

func (*HealthResponse) GetDrivers

func (m *HealthResponse) GetDrivers() int32

func (*HealthResponse) GetHealthyDrivers

func (m *HealthResponse) GetHealthyDrivers() int32

func (*HealthResponse) ProtoMessage

func (*HealthResponse) ProtoMessage()

func (*HealthResponse) Reset

func (m *HealthResponse) Reset()

func (*HealthResponse) String

func (m *HealthResponse) String() string

func (*HealthResponse) XXX_DiscardUnknown

func (m *HealthResponse) XXX_DiscardUnknown()

func (*HealthResponse) XXX_Marshal

func (m *HealthResponse) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)

func (*HealthResponse) XXX_Merge

func (m *HealthResponse) XXX_Merge(src proto.Message)

func (*HealthResponse) XXX_Size

func (m *HealthResponse) XXX_Size() int

func (*HealthResponse) XXX_Unmarshal

func (m *HealthResponse) XXX_Unmarshal(b []byte) error

type IncomingRequest

type IncomingRequest struct {
	Mzid     string               `protobuf:"bytes,1,opt,name=mzid,proto3" json:"mzid,omitempty"`
	Instance string               `protobuf:"bytes,2,opt,name=instance,proto3" json:"instance,omitempty"`
	Code     IncomingRequest_Code `protobuf:"varint,3,opt,name=code,proto3,enum=site.IncomingRequest_Code" json:"code,omitempty"`
	// user provided network properties
	Data                 string   `protobuf:"bytes,4,opt,name=data,proto3" json:"data,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-" yaml:"-"`
	XXX_unrecognized     []byte   `json:"-" yaml:"-"`
	XXX_sizecache        int32    `json:"-" yaml:"-"`
}

func (*IncomingRequest) Descriptor

func (*IncomingRequest) Descriptor() ([]byte, []int)

func (*IncomingRequest) GetCode

func (*IncomingRequest) GetData

func (m *IncomingRequest) GetData() string

func (*IncomingRequest) GetInstance added in v0.1.5

func (m *IncomingRequest) GetInstance() string

func (*IncomingRequest) GetMzid

func (m *IncomingRequest) GetMzid() string

func (*IncomingRequest) ProtoMessage

func (*IncomingRequest) ProtoMessage()

func (*IncomingRequest) Reset

func (m *IncomingRequest) Reset()

func (*IncomingRequest) String

func (m *IncomingRequest) String() string

func (*IncomingRequest) XXX_DiscardUnknown

func (m *IncomingRequest) XXX_DiscardUnknown()

func (*IncomingRequest) XXX_Marshal

func (m *IncomingRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)

func (*IncomingRequest) XXX_Merge

func (m *IncomingRequest) XXX_Merge(src proto.Message)

func (*IncomingRequest) XXX_Size

func (m *IncomingRequest) XXX_Size() int

func (*IncomingRequest) XXX_Unmarshal

func (m *IncomingRequest) XXX_Unmarshal(b []byte) error

type IncomingRequest_Code

type IncomingRequest_Code int32
const (
	IncomingRequest_Reserved IncomingRequest_Code = 0
	IncomingRequest_Setup    IncomingRequest_Code = 1
	IncomingRequest_Teardown IncomingRequest_Code = 2
)

func (IncomingRequest_Code) EnumDescriptor

func (IncomingRequest_Code) EnumDescriptor() ([]byte, []int)

func (IncomingRequest_Code) String

func (x IncomingRequest_Code) String() string

type IncomingResponse

type IncomingResponse struct {
	XXX_NoUnkeyedLiteral struct{} `json:"-" yaml:"-"`
	XXX_unrecognized     []byte   `json:"-" yaml:"-"`
	XXX_sizecache        int32    `json:"-" yaml:"-"`
}

func (*IncomingResponse) Descriptor

func (*IncomingResponse) Descriptor() ([]byte, []int)

func (*IncomingResponse) ProtoMessage

func (*IncomingResponse) ProtoMessage()

func (*IncomingResponse) Reset

func (m *IncomingResponse) Reset()

func (*IncomingResponse) String

func (m *IncomingResponse) String() string

func (*IncomingResponse) XXX_DiscardUnknown

func (m *IncomingResponse) XXX_DiscardUnknown()

func (*IncomingResponse) XXX_Marshal

func (m *IncomingResponse) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)

func (*IncomingResponse) XXX_Merge

func (m *IncomingResponse) XXX_Merge(src proto.Message)

func (*IncomingResponse) XXX_Size

func (m *IncomingResponse) XXX_Size() int

func (*IncomingResponse) XXX_Unmarshal

func (m *IncomingResponse) XXX_Unmarshal(b []byte) error

type InterfaceModel added in v0.1.3

type InterfaceModel struct {
	Vlid                 string   `protobuf:"bytes,1,opt,name=vlid,proto3" json:"vlid,omitempty"`
	Phyid                string   `protobuf:"bytes,3,opt,name=phyid,proto3" json:"phyid,omitempty"`
	Model                string   `protobuf:"bytes,2,opt,name=model,proto3" json:"model,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-" yaml:"-"`
	XXX_unrecognized     []byte   `json:"-" yaml:"-"`
	XXX_sizecache        int32    `json:"-" yaml:"-"`
}

func (*InterfaceModel) Descriptor added in v0.1.3

func (*InterfaceModel) Descriptor() ([]byte, []int)

func (*InterfaceModel) GetModel added in v0.1.3

func (m *InterfaceModel) GetModel() string

func (*InterfaceModel) GetPhyid added in v0.1.3

func (m *InterfaceModel) GetPhyid() string

func (*InterfaceModel) GetVlid added in v0.1.3

func (m *InterfaceModel) GetVlid() string

func (*InterfaceModel) ProtoMessage added in v0.1.3

func (*InterfaceModel) ProtoMessage()

func (*InterfaceModel) Reset added in v0.1.3

func (m *InterfaceModel) Reset()

func (*InterfaceModel) String added in v0.1.3

func (m *InterfaceModel) String() string

func (*InterfaceModel) XXX_DiscardUnknown added in v0.1.3

func (m *InterfaceModel) XXX_DiscardUnknown()

func (*InterfaceModel) XXX_Marshal added in v0.1.3

func (m *InterfaceModel) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)

func (*InterfaceModel) XXX_Merge added in v0.1.3

func (m *InterfaceModel) XXX_Merge(src proto.Message)

func (*InterfaceModel) XXX_Size added in v0.1.3

func (m *InterfaceModel) XXX_Size() int

func (*InterfaceModel) XXX_Unmarshal added in v0.1.3

func (m *InterfaceModel) XXX_Unmarshal(b []byte) error

type LinkDriverClient

type LinkDriverClient interface {
	Health(ctx context.Context, in *HealthRequest, opts ...grpc.CallOption) (*HealthResponse, error)
	CreateLink(ctx context.Context, in *MzRequest, opts ...grpc.CallOption) (*MzResponse, error)
	DestroyLink(ctx context.Context, in *MzRequest, opts ...grpc.CallOption) (*MzResponse, error)
	ModifyLink(ctx context.Context, in *MzRequest, opts ...grpc.CallOption) (*MzResponse, error)
	ConnectLink(ctx context.Context, in *MzRequest, opts ...grpc.CallOption) (*MzResponse, error)
	DisconnectLink(ctx context.Context, in *MzRequest, opts ...grpc.CallOption) (*MzResponse, error)
	NotifyIncoming(ctx context.Context, in *IncomingRequest, opts ...grpc.CallOption) (*IncomingResponse, error)
}

LinkDriverClient is the client API for LinkDriver service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.

func NewLinkDriverClient

func NewLinkDriverClient(cc *grpc.ClientConn) LinkDriverClient

type LinkDriverServer

type LinkDriverServer interface {
	Health(context.Context, *HealthRequest) (*HealthResponse, error)
	CreateLink(context.Context, *MzRequest) (*MzResponse, error)
	DestroyLink(context.Context, *MzRequest) (*MzResponse, error)
	ModifyLink(context.Context, *MzRequest) (*MzResponse, error)
	ConnectLink(context.Context, *MzRequest) (*MzResponse, error)
	DisconnectLink(context.Context, *MzRequest) (*MzResponse, error)
	NotifyIncoming(context.Context, *IncomingRequest) (*IncomingResponse, error)
}

LinkDriverServer is the server API for LinkDriver service.

type LinkModel added in v0.1.3

type LinkModel struct {
	// virtual link id
	Vlid string `protobuf:"bytes,1,opt,name=vlid,proto3" json:"vlid,omitempty"`
	// How many experiment lanes each physical testbed network segment carries.
	// Maps physical testbed link IDs to a number of lanes. A LinkModel is the
	// mapping of an experiment link over a set of testbed links. For any given
	// nodes X and Y in a testbed, it will generally require several hops (across
	// switches and the like) to get from X to Y. A Lane indicates residency of a
	// unique LinkModel on a particular testbed link segment. Thus, while a single
	// LinkModel will not impart multiple lanes across testbed link segments,
	// LinkModels exist as a part of a broader experiment and can create multiple
	// experiment lanes of traffic running over a testbed link segments. This map
	// captures that multi-tenancy so that the provisioning systems responsible
	// for implementing this link model are aware of the lane configuration and
	// and setup the corresponding virtual link appropriately.
	Lanes map[string]uint32 `` /* 152-byte string literal not displayed */
	// json
	Model string `protobuf:"bytes,3,opt,name=model,proto3" json:"model,omitempty"`
	// endpoints that are a part of this link
	Endpoints            []string `protobuf:"bytes,4,rep,name=endpoints,proto3" json:"endpoints,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-" yaml:"-"`
	XXX_unrecognized     []byte   `json:"-" yaml:"-"`
	XXX_sizecache        int32    `json:"-" yaml:"-"`
}

func (*LinkModel) Descriptor added in v0.1.3

func (*LinkModel) Descriptor() ([]byte, []int)

func (*LinkModel) GetEndpoints added in v0.1.6

func (m *LinkModel) GetEndpoints() []string

func (*LinkModel) GetLanes added in v0.1.3

func (m *LinkModel) GetLanes() map[string]uint32

func (*LinkModel) GetModel added in v0.1.3

func (m *LinkModel) GetModel() string

func (*LinkModel) GetVlid added in v0.1.3

func (m *LinkModel) GetVlid() string

func (*LinkModel) ProtoMessage added in v0.1.3

func (*LinkModel) ProtoMessage()

func (*LinkModel) Reset added in v0.1.3

func (m *LinkModel) Reset()

func (*LinkModel) String added in v0.1.3

func (m *LinkModel) String() string

func (*LinkModel) XXX_DiscardUnknown added in v0.1.3

func (m *LinkModel) XXX_DiscardUnknown()

func (*LinkModel) XXX_Marshal added in v0.1.3

func (m *LinkModel) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)

func (*LinkModel) XXX_Merge added in v0.1.3

func (m *LinkModel) XXX_Merge(src proto.Message)

func (*LinkModel) XXX_Size added in v0.1.3

func (m *LinkModel) XXX_Size() int

func (*LinkModel) XXX_Unmarshal added in v0.1.3

func (m *LinkModel) XXX_Unmarshal(b []byte) error

type MzFragment

type MzFragment struct {
	Id        string   `protobuf:"bytes,1,opt,name=id,proto3" json:"id,omitempty"`
	Elements  []string `protobuf:"bytes,2,rep,name=elements,proto3" json:"elements,omitempty"`
	Resources []string `protobuf:"bytes,3,rep,name=resources,proto3" json:"resources,omitempty"`
	// Types that are valid to be assigned to Model:
	//	*MzFragment_NodeModel
	//	*MzFragment_LinkModel
	//	*MzFragment_AssetModel
	Model                isMzFragment_Model `protobuf_oneof:"model"`
	Allocation           string             `protobuf:"bytes,6,opt,name=allocation,proto3" json:"allocation,omitempty"`
	State                MzFragment_State   `protobuf:"varint,7,opt,name=state,proto3,enum=site.MzFragment_State" json:"state,omitempty"`
	Error                string             `protobuf:"bytes,8,opt,name=error,proto3" json:"error,omitempty"`
	XXX_NoUnkeyedLiteral struct{}           `json:"-" yaml:"-"`
	XXX_unrecognized     []byte             `json:"-" yaml:"-"`
	XXX_sizecache        int32              `json:"-" yaml:"-"`
}

func (*MzFragment) Descriptor

func (*MzFragment) Descriptor() ([]byte, []int)

func (*MzFragment) GetAllocation

func (m *MzFragment) GetAllocation() string

func (*MzFragment) GetAssetModel added in v0.2.0

func (m *MzFragment) GetAssetModel() *AssetModel

func (*MzFragment) GetElements

func (m *MzFragment) GetElements() []string

func (*MzFragment) GetError added in v0.1.2

func (m *MzFragment) GetError() string

func (*MzFragment) GetId

func (m *MzFragment) GetId() string

func (*MzFragment) GetLinkModel added in v0.1.3

func (m *MzFragment) GetLinkModel() *LinkModel

func (*MzFragment) GetModel

func (m *MzFragment) GetModel() isMzFragment_Model

func (*MzFragment) GetNodeModel added in v0.1.3

func (m *MzFragment) GetNodeModel() *NodeModel

func (*MzFragment) GetResources

func (m *MzFragment) GetResources() []string

func (*MzFragment) GetState

func (m *MzFragment) GetState() MzFragment_State

func (*MzFragment) ProtoMessage

func (*MzFragment) ProtoMessage()

func (*MzFragment) Reset

func (m *MzFragment) Reset()

func (*MzFragment) String

func (m *MzFragment) String() string

func (*MzFragment) XXX_DiscardUnknown

func (m *MzFragment) XXX_DiscardUnknown()

func (*MzFragment) XXX_Marshal

func (m *MzFragment) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)

func (*MzFragment) XXX_Merge

func (m *MzFragment) XXX_Merge(src proto.Message)

func (*MzFragment) XXX_OneofWrappers added in v0.1.7

func (*MzFragment) XXX_OneofWrappers() []interface{}

XXX_OneofWrappers is for the internal use of the proto package.

func (*MzFragment) XXX_Size

func (m *MzFragment) XXX_Size() int

func (*MzFragment) XXX_Unmarshal

func (m *MzFragment) XXX_Unmarshal(b []byte) error

type MzFragment_AssetModel added in v0.2.0

type MzFragment_AssetModel struct {
	AssetModel *AssetModel `protobuf:"bytes,9,opt,name=asset_model,json=assetModel,proto3,oneof"`
}

type MzFragment_LinkModel added in v0.1.3

type MzFragment_LinkModel struct {
	LinkModel *LinkModel `protobuf:"bytes,5,opt,name=link_model,json=linkModel,proto3,oneof"`
}

type MzFragment_NodeModel added in v0.1.3

type MzFragment_NodeModel struct {
	NodeModel *NodeModel `protobuf:"bytes,4,opt,name=node_model,json=nodeModel,proto3,oneof"`
}

type MzFragment_State

type MzFragment_State int32
const (
	MzFragment_Reserved     MzFragment_State = 0
	MzFragment_Pending      MzFragment_State = 1
	MzFragment_Reticulating MzFragment_State = 2
	MzFragment_Complete     MzFragment_State = 3
	MzFragment_Error        MzFragment_State = 4
)

func (MzFragment_State) EnumDescriptor

func (MzFragment_State) EnumDescriptor() ([]byte, []int)

func (MzFragment_State) String

func (x MzFragment_State) String() string

type MzRequest

type MzRequest struct {
	Mzid                 string        `protobuf:"bytes,1,opt,name=mzid,proto3" json:"mzid,omitempty"`
	Instance             string        `protobuf:"bytes,2,opt,name=instance,proto3" json:"instance,omitempty"`
	Fragments            []*MzFragment `protobuf:"bytes,3,rep,name=fragments,proto3" json:"fragments,omitempty"`
	XXX_NoUnkeyedLiteral struct{}      `json:"-" yaml:"-"`
	XXX_unrecognized     []byte        `json:"-" yaml:"-"`
	XXX_sizecache        int32         `json:"-" yaml:"-"`
}

func (*MzRequest) Descriptor

func (*MzRequest) Descriptor() ([]byte, []int)

func (*MzRequest) GetFragments

func (m *MzRequest) GetFragments() []*MzFragment

func (*MzRequest) GetInstance added in v0.1.5

func (m *MzRequest) GetInstance() string

func (*MzRequest) GetMzid

func (m *MzRequest) GetMzid() string

func (*MzRequest) ProtoMessage

func (*MzRequest) ProtoMessage()

func (*MzRequest) Reset

func (m *MzRequest) Reset()

func (*MzRequest) String

func (m *MzRequest) String() string

func (*MzRequest) XXX_DiscardUnknown

func (m *MzRequest) XXX_DiscardUnknown()

func (*MzRequest) XXX_Marshal

func (m *MzRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)

func (*MzRequest) XXX_Merge

func (m *MzRequest) XXX_Merge(src proto.Message)

func (*MzRequest) XXX_Size

func (m *MzRequest) XXX_Size() int

func (*MzRequest) XXX_Unmarshal

func (m *MzRequest) XXX_Unmarshal(b []byte) error

type MzResponse

type MzResponse struct {
	Mzid                 string      `protobuf:"bytes,1,opt,name=mzid,proto3" json:"mzid,omitempty"`
	Instance             string      `protobuf:"bytes,2,opt,name=instance,proto3" json:"instance,omitempty"`
	Results              []*OpResult `protobuf:"bytes,3,rep,name=results,proto3" json:"results,omitempty"`
	XXX_NoUnkeyedLiteral struct{}    `json:"-" yaml:"-"`
	XXX_unrecognized     []byte      `json:"-" yaml:"-"`
	XXX_sizecache        int32       `json:"-" yaml:"-"`
}

func (*MzResponse) Descriptor

func (*MzResponse) Descriptor() ([]byte, []int)

func (*MzResponse) GetInstance added in v0.1.5

func (m *MzResponse) GetInstance() string

func (*MzResponse) GetMzid

func (m *MzResponse) GetMzid() string

func (*MzResponse) GetResults

func (m *MzResponse) GetResults() []*OpResult

func (*MzResponse) ProtoMessage

func (*MzResponse) ProtoMessage()

func (*MzResponse) Reset

func (m *MzResponse) Reset()

func (*MzResponse) String

func (m *MzResponse) String() string

func (*MzResponse) XXX_DiscardUnknown

func (m *MzResponse) XXX_DiscardUnknown()

func (*MzResponse) XXX_Marshal

func (m *MzResponse) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)

func (*MzResponse) XXX_Merge

func (m *MzResponse) XXX_Merge(src proto.Message)

func (*MzResponse) XXX_Size

func (m *MzResponse) XXX_Size() int

func (*MzResponse) XXX_Unmarshal

func (m *MzResponse) XXX_Unmarshal(b []byte) error

type NodeDriverClient

type NodeDriverClient interface {
	Health(ctx context.Context, in *HealthRequest, opts ...grpc.CallOption) (*HealthResponse, error)
	Setup(ctx context.Context, in *MzRequest, opts ...grpc.CallOption) (*MzResponse, error)
	Configure(ctx context.Context, in *MzRequest, opts ...grpc.CallOption) (*MzResponse, error)
	Restart(ctx context.Context, in *MzRequest, opts ...grpc.CallOption) (*MzResponse, error)
	Reset(ctx context.Context, in *MzRequest, opts ...grpc.CallOption) (*MzResponse, error)
	TurnOn(ctx context.Context, in *MzRequest, opts ...grpc.CallOption) (*MzResponse, error)
	TurnOff(ctx context.Context, in *MzRequest, opts ...grpc.CallOption) (*MzResponse, error)
	NotifyIncoming(ctx context.Context, in *IncomingRequest, opts ...grpc.CallOption) (*IncomingResponse, error)
}

NodeDriverClient is the client API for NodeDriver service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.

func NewNodeDriverClient

func NewNodeDriverClient(cc *grpc.ClientConn) NodeDriverClient

type NodeDriverServer

NodeDriverServer is the server API for NodeDriver service.

type NodeModel added in v0.1.3

type NodeModel struct {
	Model                string            `protobuf:"bytes,1,opt,name=model,proto3" json:"model,omitempty"`
	Interfaces           []*InterfaceModel `protobuf:"bytes,2,rep,name=interfaces,proto3" json:"interfaces,omitempty"`
	XXX_NoUnkeyedLiteral struct{}          `json:"-" yaml:"-"`
	XXX_unrecognized     []byte            `json:"-" yaml:"-"`
	XXX_sizecache        int32             `json:"-" yaml:"-"`
}

func (*NodeModel) Descriptor added in v0.1.3

func (*NodeModel) Descriptor() ([]byte, []int)

func (*NodeModel) GetInterfaces added in v0.1.3

func (m *NodeModel) GetInterfaces() []*InterfaceModel

func (*NodeModel) GetModel added in v0.1.3

func (m *NodeModel) GetModel() string

func (*NodeModel) ProtoMessage added in v0.1.3

func (*NodeModel) ProtoMessage()

func (*NodeModel) Reset added in v0.1.3

func (m *NodeModel) Reset()

func (*NodeModel) String added in v0.1.3

func (m *NodeModel) String() string

func (*NodeModel) XXX_DiscardUnknown added in v0.1.3

func (m *NodeModel) XXX_DiscardUnknown()

func (*NodeModel) XXX_Marshal added in v0.1.3

func (m *NodeModel) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)

func (*NodeModel) XXX_Merge added in v0.1.3

func (m *NodeModel) XXX_Merge(src proto.Message)

func (*NodeModel) XXX_Size added in v0.1.3

func (m *NodeModel) XXX_Size() int

func (*NodeModel) XXX_Unmarshal added in v0.1.3

func (m *NodeModel) XXX_Unmarshal(b []byte) error

type OpResult

type OpResult struct {
	ResourceId           string        `protobuf:"bytes,1,opt,name=resourceId,proto3" json:"resourceId,omitempty"`
	Msg                  []*Diagnostic `protobuf:"bytes,2,rep,name=msg,proto3" json:"msg,omitempty"`
	Updates              []*MzFragment `protobuf:"bytes,3,rep,name=updates,proto3" json:"updates,omitempty"`
	XXX_NoUnkeyedLiteral struct{}      `json:"-" yaml:"-"`
	XXX_unrecognized     []byte        `json:"-" yaml:"-"`
	XXX_sizecache        int32         `json:"-" yaml:"-"`
}

func (*OpResult) Descriptor

func (*OpResult) Descriptor() ([]byte, []int)

func (*OpResult) GetMsg

func (m *OpResult) GetMsg() []*Diagnostic

func (*OpResult) GetResourceId

func (m *OpResult) GetResourceId() string

func (*OpResult) GetUpdates added in v0.1.2

func (m *OpResult) GetUpdates() []*MzFragment

func (*OpResult) ProtoMessage

func (*OpResult) ProtoMessage()

func (*OpResult) Reset

func (m *OpResult) Reset()

func (*OpResult) String

func (m *OpResult) String() string

func (*OpResult) XXX_DiscardUnknown

func (m *OpResult) XXX_DiscardUnknown()

func (*OpResult) XXX_Marshal

func (m *OpResult) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)

func (*OpResult) XXX_Merge

func (m *OpResult) XXX_Merge(src proto.Message)

func (*OpResult) XXX_Size

func (m *OpResult) XXX_Size() int

func (*OpResult) XXX_Unmarshal

func (m *OpResult) XXX_Unmarshal(b []byte) error

type RegisterRequest

type RegisterRequest struct {
	// localhost, ipv4 or ipv6
	Host string `protobuf:"bytes,1,opt,name=host,proto3" json:"host,omitempty"`
	// port running on
	Port int32 `protobuf:"varint,2,opt,name=port,proto3" json:"port,omitempty"`
	// string to tell the commander what driver it is
	Driver string `protobuf:"bytes,3,opt,name=driver,proto3" json:"driver,omitempty"`
	// a list of strings containing all uuids driver is responsible for
	// json representation
	Ids                  []string `protobuf:"bytes,4,rep,name=ids,proto3" json:"ids,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (*RegisterRequest) Descriptor

func (*RegisterRequest) Descriptor() ([]byte, []int)

func (*RegisterRequest) GetDriver

func (m *RegisterRequest) GetDriver() string

func (*RegisterRequest) GetHost

func (m *RegisterRequest) GetHost() string

func (*RegisterRequest) GetIds

func (m *RegisterRequest) GetIds() []string

func (*RegisterRequest) GetPort

func (m *RegisterRequest) GetPort() int32

func (*RegisterRequest) ProtoMessage

func (*RegisterRequest) ProtoMessage()

func (*RegisterRequest) Reset

func (m *RegisterRequest) Reset()

func (*RegisterRequest) String

func (m *RegisterRequest) String() string

func (*RegisterRequest) XXX_DiscardUnknown

func (m *RegisterRequest) XXX_DiscardUnknown()

func (*RegisterRequest) XXX_Marshal

func (m *RegisterRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)

func (*RegisterRequest) XXX_Merge

func (m *RegisterRequest) XXX_Merge(src proto.Message)

func (*RegisterRequest) XXX_Size

func (m *RegisterRequest) XXX_Size() int

func (*RegisterRequest) XXX_Unmarshal

func (m *RegisterRequest) XXX_Unmarshal(b []byte) error

type RegisterResponse

type RegisterResponse struct {
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (*RegisterResponse) Descriptor

func (*RegisterResponse) Descriptor() ([]byte, []int)

func (*RegisterResponse) ProtoMessage

func (*RegisterResponse) ProtoMessage()

func (*RegisterResponse) Reset

func (m *RegisterResponse) Reset()

func (*RegisterResponse) String

func (m *RegisterResponse) String() string

func (*RegisterResponse) XXX_DiscardUnknown

func (m *RegisterResponse) XXX_DiscardUnknown()

func (*RegisterResponse) XXX_Marshal

func (m *RegisterResponse) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)

func (*RegisterResponse) XXX_Merge

func (m *RegisterResponse) XXX_Merge(src proto.Message)

func (*RegisterResponse) XXX_Size

func (m *RegisterResponse) XXX_Size() int

func (*RegisterResponse) XXX_Unmarshal

func (m *RegisterResponse) XXX_Unmarshal(b []byte) error

type Response

type Response struct {
	Msg                  []*Diagnostic `protobuf:"bytes,2,rep,name=msg,proto3" json:"msg,omitempty"`
	XXX_NoUnkeyedLiteral struct{}      `json:"-"`
	XXX_unrecognized     []byte        `json:"-"`
	XXX_sizecache        int32         `json:"-"`
}

func (*Response) Descriptor

func (*Response) Descriptor() ([]byte, []int)

func (*Response) GetMsg

func (m *Response) GetMsg() []*Diagnostic

func (*Response) ProtoMessage

func (*Response) ProtoMessage()

func (*Response) Reset

func (m *Response) Reset()

func (*Response) String

func (m *Response) String() string

func (*Response) XXX_DiscardUnknown

func (m *Response) XXX_DiscardUnknown()

func (*Response) XXX_Marshal

func (m *Response) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)

func (*Response) XXX_Merge

func (m *Response) XXX_Merge(src proto.Message)

func (*Response) XXX_Size

func (m *Response) XXX_Size() int

func (*Response) XXX_Unmarshal

func (m *Response) XXX_Unmarshal(b []byte) error

type StatusRequest added in v0.1.2

type StatusRequest struct {
	Mzid                 string   `protobuf:"bytes,1,opt,name=mzid,proto3" json:"mzid,omitempty"`
	Instance             string   `protobuf:"bytes,2,opt,name=instance,proto3" json:"instance,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-" yaml:"-"`
	XXX_unrecognized     []byte   `json:"-" yaml:"-"`
	XXX_sizecache        int32    `json:"-" yaml:"-"`
}

func (*StatusRequest) Descriptor added in v0.1.2

func (*StatusRequest) Descriptor() ([]byte, []int)

func (*StatusRequest) GetInstance added in v0.1.5

func (m *StatusRequest) GetInstance() string

func (*StatusRequest) GetMzid added in v0.1.2

func (m *StatusRequest) GetMzid() string

func (*StatusRequest) ProtoMessage added in v0.1.2

func (*StatusRequest) ProtoMessage()

func (*StatusRequest) Reset added in v0.1.2

func (m *StatusRequest) Reset()

func (*StatusRequest) String added in v0.1.2

func (m *StatusRequest) String() string

func (*StatusRequest) XXX_DiscardUnknown added in v0.1.2

func (m *StatusRequest) XXX_DiscardUnknown()

func (*StatusRequest) XXX_Marshal added in v0.1.2

func (m *StatusRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)

func (*StatusRequest) XXX_Merge added in v0.1.2

func (m *StatusRequest) XXX_Merge(src proto.Message)

func (*StatusRequest) XXX_Size added in v0.1.2

func (m *StatusRequest) XXX_Size() int

func (*StatusRequest) XXX_Unmarshal added in v0.1.2

func (m *StatusRequest) XXX_Unmarshal(b []byte) error

type StatusResponse added in v0.1.2

type StatusResponse struct {
	Tasks                []*Task  `protobuf:"bytes,1,rep,name=tasks,proto3" json:"tasks,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-" yaml:"-"`
	XXX_unrecognized     []byte   `json:"-" yaml:"-"`
	XXX_sizecache        int32    `json:"-" yaml:"-"`
}

func (*StatusResponse) Descriptor added in v0.1.2

func (*StatusResponse) Descriptor() ([]byte, []int)

func (*StatusResponse) GetTasks added in v0.1.2

func (m *StatusResponse) GetTasks() []*Task

func (*StatusResponse) ProtoMessage added in v0.1.2

func (*StatusResponse) ProtoMessage()

func (*StatusResponse) Reset added in v0.1.2

func (m *StatusResponse) Reset()

func (*StatusResponse) String added in v0.1.2

func (m *StatusResponse) String() string

func (*StatusResponse) XXX_DiscardUnknown added in v0.1.2

func (m *StatusResponse) XXX_DiscardUnknown()

func (*StatusResponse) XXX_Marshal added in v0.1.2

func (m *StatusResponse) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)

func (*StatusResponse) XXX_Merge added in v0.1.2

func (m *StatusResponse) XXX_Merge(src proto.Message)

func (*StatusResponse) XXX_Size added in v0.1.2

func (m *StatusResponse) XXX_Size() int

func (*StatusResponse) XXX_Unmarshal added in v0.1.2

func (m *StatusResponse) XXX_Unmarshal(b []byte) error

type Task added in v0.1.2

type Task struct {
	Kind                 string   `protobuf:"bytes,1,opt,name=kind,proto3" json:"kind,omitempty"`
	Name                 string   `protobuf:"bytes,2,opt,name=name,proto3" json:"name,omitempty"`
	Error                string   `protobuf:"bytes,3,opt,name=error,proto3" json:"error,omitempty"`
	Complete             bool     `protobuf:"varint,4,opt,name=complete,proto3" json:"complete,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-" yaml:"-"`
	XXX_unrecognized     []byte   `json:"-" yaml:"-"`
	XXX_sizecache        int32    `json:"-" yaml:"-"`
}

func (*Task) Descriptor added in v0.1.2

func (*Task) Descriptor() ([]byte, []int)

func (*Task) GetComplete added in v0.1.2

func (m *Task) GetComplete() bool

func (*Task) GetError added in v0.1.2

func (m *Task) GetError() string

func (*Task) GetKind added in v0.1.2

func (m *Task) GetKind() string

func (*Task) GetName added in v0.1.2

func (m *Task) GetName() string

func (*Task) ProtoMessage added in v0.1.2

func (*Task) ProtoMessage()

func (*Task) Reset added in v0.1.2

func (m *Task) Reset()

func (*Task) String added in v0.1.2

func (m *Task) String() string

func (*Task) XXX_DiscardUnknown added in v0.1.2

func (m *Task) XXX_DiscardUnknown()

func (*Task) XXX_Marshal added in v0.1.2

func (m *Task) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)

func (*Task) XXX_Merge added in v0.1.2

func (m *Task) XXX_Merge(src proto.Message)

func (*Task) XXX_Size added in v0.1.2

func (m *Task) XXX_Size() int

func (*Task) XXX_Unmarshal added in v0.1.2

func (m *Task) XXX_Unmarshal(b []byte) error

type UnregisterRequest

type UnregisterRequest struct {
	// localhost, ipv4 or ipv6
	Host string `protobuf:"bytes,1,opt,name=host,proto3" json:"host,omitempty"`
	// port running on
	Port int32 `protobuf:"varint,2,opt,name=port,proto3" json:"port,omitempty"`
	// string to tell the commander what driver it is
	Driver string `protobuf:"bytes,3,opt,name=driver,proto3" json:"driver,omitempty"`
	// a list of strings containing all uuids driver is responsible for
	// json representation
	Ids                  []string `protobuf:"bytes,4,rep,name=ids,proto3" json:"ids,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (*UnregisterRequest) Descriptor

func (*UnregisterRequest) Descriptor() ([]byte, []int)

func (*UnregisterRequest) GetDriver

func (m *UnregisterRequest) GetDriver() string

func (*UnregisterRequest) GetHost

func (m *UnregisterRequest) GetHost() string

func (*UnregisterRequest) GetIds

func (m *UnregisterRequest) GetIds() []string

func (*UnregisterRequest) GetPort

func (m *UnregisterRequest) GetPort() int32

func (*UnregisterRequest) ProtoMessage

func (*UnregisterRequest) ProtoMessage()

func (*UnregisterRequest) Reset

func (m *UnregisterRequest) Reset()

func (*UnregisterRequest) String

func (m *UnregisterRequest) String() string

func (*UnregisterRequest) XXX_DiscardUnknown

func (m *UnregisterRequest) XXX_DiscardUnknown()

func (*UnregisterRequest) XXX_Marshal

func (m *UnregisterRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)

func (*UnregisterRequest) XXX_Merge

func (m *UnregisterRequest) XXX_Merge(src proto.Message)

func (*UnregisterRequest) XXX_Size

func (m *UnregisterRequest) XXX_Size() int

func (*UnregisterRequest) XXX_Unmarshal

func (m *UnregisterRequest) XXX_Unmarshal(b []byte) error

type UnregisterResponse

type UnregisterResponse struct {
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (*UnregisterResponse) Descriptor

func (*UnregisterResponse) Descriptor() ([]byte, []int)

func (*UnregisterResponse) ProtoMessage

func (*UnregisterResponse) ProtoMessage()

func (*UnregisterResponse) Reset

func (m *UnregisterResponse) Reset()

func (*UnregisterResponse) String

func (m *UnregisterResponse) String() string

func (*UnregisterResponse) XXX_DiscardUnknown

func (m *UnregisterResponse) XXX_DiscardUnknown()

func (*UnregisterResponse) XXX_Marshal

func (m *UnregisterResponse) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)

func (*UnregisterResponse) XXX_Merge

func (m *UnregisterResponse) XXX_Merge(src proto.Message)

func (*UnregisterResponse) XXX_Size

func (m *UnregisterResponse) XXX_Size() int

func (*UnregisterResponse) XXX_Unmarshal

func (m *UnregisterResponse) XXX_Unmarshal(b []byte) error

Jump to